@@ -24,10 +24,11 @@
 
 __doc__ = """eXistDA product module."""
 
-from Globals import HTMLFile
-from Globals import MessageDialog
-from Globals import Persistent
+from App.special_dtml import HTMLFile
+from App.Dialogs import MessageDialog
+from Persistence import Persistent
 from AccessControl import ClassSecurityInfo
+from App.class_init import InitializeClass
 
 import OFS.SimpleItem
 import Acquisition
@@ -38,8 +39,8 @@ import xmlrpclib, urllib
 from xmlrpclib import Binary
 from types import StringType
 
-from eXistDA_utils import iseXistURI, isHTTPURI
-import eXistDA_utils as utils
+from utils import iseXistURI, isHTTPURI
+import utils
 import eXistDAresult
 import xslt
 
@@ -882,8 +883,4 @@ Executes an XPATH query or an XQuery on the DB.
         # return raw xml data set
         return res
 
-
-
-import Globals
-Globals.InitializeClass(eXistDA)
-
+InitializeClass(eXistDA)
